@@ -10,25 +10,28 @@ module CmdLine(
 import Control.Monad.Extra
 import Data.Char
 import Data.List
-import System.Console.ANSI(hSupportsANSI)
-import System.Console.CmdArgs.Implicit
-import System.Console.CmdArgs.Explicit(helpText, HelpFormat(..))
-import System.Directory.Extra
-import System.Exit
-import System.FilePath
-import System.IO
-import System.Process(readProcess)
-import Language.Preprocessor.Cpphs
+import Data.Maybe
+import Data.Functor
 import HSE.All(CppFlags(..))
 import Language.Haskell.Exts(defaultParseMode, baseLanguage)
 import Language.Haskell.Exts.Extension
-import Data.Maybe
+import Language.Preprocessor.Cpphs
+import System.Console.ANSI(hSupportsANSI)
+import System.Console.CmdArgs.Explicit(helpText, HelpFormat(..))
+import System.Console.CmdArgs.Implicit
+import System.Directory.Extra
 import System.Environment.Extra
+import System.Exit
+import System.FilePath
+import System.IO
+import System.IO.Error
 import System.Info.Extra
+import System.Process
 
 import Util
 import Paths_hlint
 import Data.Version
+import Prelude
 
 
 getCmd :: [String] -> IO Cmd
@@ -113,6 +116,7 @@ data Cmd
         ,cmdNoSummary :: Bool           -- ^ do not show the summary info
         ,cmdOnly :: [String]            -- ^ specify which hints explicitly
         ,cmdNoExitCode :: Bool
+        ,cmdTiming :: Bool
         ,cmdSerialise :: Bool           -- ^ Display hints in serialisation format
         ,cmdRefactor :: Bool            -- ^ Run the `refactor` executable to automatically perform hints
         ,cmdRefactorOptions :: String   -- ^ Options to pass to the `refactor` executable.
@@ -175,10 +179,11 @@ mode = cmdArgsMode $ modes
         ,cmdNoSummary = nam_ "no-summary" &= help "Do not show summary information"
         ,cmdOnly = nam "only" &= typ "HINT" &= help "Specify which hints explicitly"
         ,cmdNoExitCode = nam_ "no-exit-code" &= help "Do not give a negative exit if hints"
+        ,cmdTiming = nam_ "timing" &= help "Display timing information"
         ,cmdSerialise = nam_ "serialise" &= help "Serialise hint data for consumption by apply-refact"
         ,cmdRefactor = nam_ "refactor" &= help "Automatically invoke `refactor` to apply hints"
         ,cmdRefactorOptions = nam_ "refactor-options" &= typ "OPTIONS" &= help "Options to pass to the `refactor` executable"
-        , cmdWithRefactor = nam_ "with-refactor" &= help "Give the path to refactor"
+        ,cmdWithRefactor = nam_ "with-refactor" &= help "Give the path to refactor"
         } &= auto &= explicit &= name "lint"
     ,CmdGrep
         {cmdFiles = def &= args &= typ "FILE/DIR"
@@ -217,11 +222,12 @@ cmdHintFiles cmd = do
         -- we follow the stylish-haskell config file search policy
         -- 1) current directory or its ancestors; 2) home directory
         curdir <- getCurrentDirectory
-        home <- getHomeDirectory
+        -- Ignores home directory when it isn't present.
+        home <- catchIOError ((:[]) <$> getHomeDirectory) (const $ return [])
         b <- doesFileExist ".hlint.yaml"
         implicit <- findM doesFileExist $
             "HLint.hs" : -- the default in HLint 1.*
-            map (</> ".hlint.yaml") (ancestors curdir ++ [home]) -- to match Stylish Haskell
+            map (</> ".hlint.yaml") (ancestors curdir ++ home) -- to match Stylish Haskell
         return $ explicit1 ++ maybeToList implicit ++ explicit2
     where
         ancestors = init . map joinPath . reverse . inits . splitPath
@@ -310,7 +316,7 @@ getExtensions args = (lang, foldl f (if null langs then defaultExtensions else [
         f a "Haskell98" = []
         f a ('N':'o':x) | Just x <- readExtension x = delete x a
         f a x | Just x <- readExtension x = x : delete x a
-        f a x = exitMessageImpure $ "Unknown extension: " ++ x
+        f a x = UnknownExtension x : delete (UnknownExtension x) a
 
 
 readExtension :: String -> Maybe Extension
