@@ -20,6 +20,7 @@ import Util
 import Data.Char
 import Data.List.Extra
 import Data.Maybe
+import Timing
 import Language.Preprocessor.Cpphs
 import Data.Set (Set)
 import qualified Data.Map as Map
@@ -143,7 +144,7 @@ data ParseError = ParseError
 -- | Parse a Haskell module. Applies the C pre processor, and uses best-guess fixity resolution if there are ambiguities.
 --   The filename @-@ is treated as @stdin@. Requires some flags (often 'defaultParseFlags'), the filename, and optionally the contents of that file.
 parseModuleEx :: ParseFlags -> FilePath -> Maybe String -> IO (Either ParseError (Module SrcSpanInfo, [Comment]))
-parseModuleEx flags file str = do
+parseModuleEx flags file str = timedIO "Parse" file $ do
         str <- case str of
             Just x -> return x
             Nothing | file == "-" -> getContents
